pub struct ConcurrentDiagnostics {
state: Option<Arc<ConcurrentDiagnosticState>>,
}Expand description
Shared diagnostics for for_each_concurrent/try_for_each_concurrent
child futures.
Fields
state: Option<Arc<ConcurrentDiagnosticState>>Implementations
Sourceimpl ConcurrentDiagnostics
impl ConcurrentDiagnostics
Sourcepub fn new(
name: &'static str,
module_path: &'static str,
file: &'static str,
line: u32,
) -> Self
pub fn new( name: &'static str, module_path: &'static str, file: &'static str, line: u32, ) -> Self
Creates a diagnostics handle for one concurrent stream operator.
Sourcepub fn wrap<F: FnOnce() -> T, T>(
&self,
inner: F,
) -> ConcurrentDiagnosticFuture<T> ⓘ
pub fn wrap<F: FnOnce() -> T, T>( &self, inner: F, ) -> ConcurrentDiagnosticFuture<T> ⓘ
Wraps one child future produced by a concurrent stream operator.